BoxedNodeSend

Struct BoxedNodeSend 

pub struct BoxedNodeSend(pub Box<dyn Node + Send>);
A wrapper around a Box<dyn Node>.

Provides the necessary Sized implementation to allow for compatibility with the graph process function.

Useful when the ability to send nodes from one thread to another is required. E.g. this is common when initialising nodes or the audio graph itself on one thread before sending them to the audio thread.

Tuple Fields

0: Box<dyn Node + Send>

Implementations

Source

impl BoxedNodeSend

pub fn new<T>(node: T) -> Self
where T: 'static + Node + Send,

Create a new BoxedNode around the given node.

This is short-hand for BoxedNode::from(Box::new(node)).